root@proxmox04:/opt/venv/check_zpools/bin# zpool status -j
{"output_version":{"command":"zpool status","vers_major":0,"vers_minor":1},"pools":{"rpool":{"name":"rpool","state":"ONLINE","pool_guid":"9142134393397012115","txg":"2632990","spa_version":"5000","zpl_version":"5","scan_stats":{"function":"SCRUB","state":"FINISHED","start_time":"Sun Nov 16 08:00:01 CET 2025","end_time":"Sun Nov 16 08:00:21 CET 2025","to_examine":"8.29G","examined":"8.31G","skipped":"1.19M","processed":"0B","errors":"0","bytes_per_scan":"0B","pass_start":"1763276401","scrub_pause":"-","scrub_spent_paused":"0","issued_bytes_per_scan":"8.28G","issued":"8.28G"},"vdevs":{"rpool":{"name":"rpool","vdev_type":"root","guid":"9142134393397012115","class":"normal","state":"ONLINE","alloc_space":"9.35G","total_space":"464G","def_space":"464G","read_errors":"0","write_errors":"0","checksum_errors":"0","vdevs":{"mirror-0":{"name":"mirror-0","vdev_type":"mirror","guid":"7891719379031656730","class":"normal","state":"ONLINE","alloc_space":"9.35G","total_space":"464G","def_space":"464G","rep_dev_size":"464G","read_errors":"0","write_errors":"0","checksum_errors":"0","vdevs":{"wwn-0x5002538f54c19521-part3":{"name":"wwn-0x5002538f54c19521-part3","vdev_type":"disk","guid":"4048583111419936454","path":"/dev/disk/by-id/wwn-0x5002538f54c19521-part3","class":"normal","state":"ONLINE","rep_dev_size":"464G","phys_space":"465G","read_errors":"0","write_errors":"0","checksum_errors":"0","slow_ios":"0"},"wwn-0x5002538f54c194cf-part3":{"name":"wwn-0x5002538f54c194cf-part3","vdev_type":"disk","guid":"14642287321137169942","path":"/dev/disk/by-id/wwn-0x5002538f54c194cf-part3","class":"normal","state":"ONLINE","rep_dev_size":"464G","phys_space":"465G","read_errors":"0","write_errors":"0","checksum_errors":"0","slow_ios":"0"}}}}}},"error_count":"0"},"zpool-nvme":{"name":"zpool-nvme","state":"ONLINE","pool_guid":"15707285985305284701","txg":"2455392","spa_version":"5000","zpl_version":"5","scan_stats":{"function":"SCRUB","state":"FINISHED","start_time":"Sun Nov 16 08:00:01 CET 2025","end_time":"Sun Nov 16 08:00:17 CET 2025","to_examine":"24.0G","examined":"24.0G","skipped":"1.61M","processed":"0B","errors":"0","bytes_per_scan":"0B","pass_start":"1763276402","scrub_pause":"-","scrub_spent_paused":"0","issued_bytes_per_scan":"24.0G","issued":"24.0G"},"vdevs":{"zpool-nvme":{"name":"zpool-nvme","vdev_type":"root","guid":"15707285985305284701","class":"normal","state":"ONLINE","alloc_space":"24.2G","total_space":"3.62T","def_space":"3.62T","read_errors":"0","write_errors":"0","checksum_errors":"0","vdevs":{"nvme0n1":{"name":"nvme0n1","vdev_type":"disk","guid":"17801280979639684986","path":"/dev/nvme0n1p1","phys_path":"pci-0000:02:00.0-nvme-1","devid":"nvme-Seagate_FireCuda_530_ZP4000GM30013_7VS010DE-part1","class":"normal","state":"ONLINE","alloc_space":"24.2G","total_space":"3.62T","def_space":"3.62T","rep_dev_size":"3.63T","phys_space":"3.64T","read_errors":"0","write_errors":"0","checksum_errors":"0","slow_ios":"0"}}}},"error_count":"0"}}}
